==> owncloud-6.0.1.tgz: owncloud/apps/calendar/l10n/da.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ikke alle kalendere er fuldstændig cached",
"Everything seems to be completely cached" => "Alt ser ud til at være cached",
"No calendars found." => "Der blev ikke fundet nogen kalendere.",
"No events found." => "Der blev ikke fundet nogen begivenheder.",
"Wrong calendar" => "Forkert kalender",
"You do not have the permissions to edit this event." => "Du har ikke rettigheder til at redigere denne begivenhed.",
"The file contained either no events or all events are already saved in your calendar." => "Enten indeholdt filen ingen begivenheder, eller også er alle begivenheder allerede gemt i din kalender.",
"events has been saved in the new calendar" => "begivenheder er gemt i den nye kalender",
"Import failed" => "Import mislykkedes",
"events has been saved in your calendar" => "begivenheder er gemt i din kalender",
"New Timezone:" => "Ny tidszone:",
"Timezone changed" => "Tidszone ændret",
"Invalid request" => "Ugyldig forespørgsel",
"Calendar" => "Kalender",
"Deletion failed" => "Fejl ved sletning",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "gruppe",
"can edit" => "kan redigere",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Søndag",
"Monday" => "Mandag",
"Tuesday" => "Tirsdag",
"Wednesday" => "Onsdag",
"Thursday" => "Torsdag",
"Friday" => "Fredag",
"Saturday" => "Lørdag",
"Sun." => "Søn.",
"Mon." => "Man.",
"Tue." => "Tir.",
"Wed." => "Ons.",
"Thu." => "Tor.",
"Fri." => "Fre.",
"Sat." => "Lør.",
"January" => "Januar",
"February" => "Februar",
"March" => "Marts",
"April" => "April",
"May" => "Maj",
"June" => "Juni",
"July" => "Juli",
"August" => "August",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "December",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Maj",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Hele dagen",
"New Calendar" => "Ny kalender",
"Missing or invalid fields" => "Manglende eller ugyldige felter",
"Title" => "Titel",
"From Date" => "Fra dato",
"From Time" => "Fra tidspunkt",
"To Date" => "Til dato",
"To Time" => "Til tidspunkt",
"The event ends before it starts" => "Begivenheden slutter, inden den begynder",
"There was a database fail" => "Der var en fejl i databasen",
"Birthday" => "Fødselsdag",
"Business" => "Erhverv",
"Call" => "Ring",
"Clients" => "Kunder",
"Deliverer" => "Leverance",
"Holidays" => "Helligdage",
"Ideas" => "Ideer",
"Journey" => "Rejse",
"Jubilee" => "Jubilæum",
"Meeting" => "Møde",
"Other" => "Andet",
"Personal" => "Privat",
"Projects" => "Projekter",
"Questions" => "Spørgsmål",
"Work" => "Arbejde",
"by" => "af",
"unnamed" => "unavngivet",
"You do not have the permissions to update this calendar." => "Du har ikke rettigheder til at opdatere denne kalender.",
"You do not have the permissions to delete this calendar." => "Du har ikke rettigheder til at slette denne kalender.",
"You do not have the permissions to add to this calendar." => "Du har ikke rettigheder til at tilføje til denne kalender.",
"You do not have the permissions to add events to this calendar." => "Du har ikke rettigheder til at tilføje begivenheder til denne kalender.",
"You do not have the permissions to delete this event." => "Du har ikke rettigheder til at slette denne begivenhed.",
"Busy" => "Optaget",
"Does not repeat" => "Gentages ikke",
"Daily" => "Dagligt",
"Weekly" => "Ugentligt",
"Every Weekday" => "Alle hverdage",
"Bi-Weekly" => "Hver anden uge",
"Monthly" => "Månedligt",
"Yearly" => "Årligt",
"never" => "aldrig",
"by occurrences" => "efter forekomster",
"by date" => "efter dato",
"by monthday" => "efter dag i måneden",
"by weekday" => "efter ugedag",
"events week of month" => "begivenhedens uge i måneden",
"first" => "første",
"second" => "anden",
"third" => "tredje",
"fourth" => "fjerde",
"fifth" => "femte",
"last" => "sidste",
"by events date" => "efter begivenheders dato",
"by yearday(s)" => "efter dag(e) i året",
"by weeknumber(s)" => "efter ugenummer/-numre",
"by day and month" => "efter dag og måned",
"Contact birthdays" => "Kontakt fødselsdage",
"Date" => "Dato",
"Cal." => "Kal.",
"Day" => "Dag",
"Week" => "Uge",
"Month" => "Måned",
"Today" => "I dag",
"Settings" => "Indstillinger",
"Share Calendar" => "Del kalender",
"CalDav Link" => "CalDav-link",
"Download" => "Hent",
"Edit" => "Rediger",
"Delete" => "Slet",
"New calendar" => "Ny kalender",
"Edit calendar" => "Rediger kalender",
"Displayname" => "Vist navn",
"Calendar color" => "Kalenderfarve",
"Save" => "Gem",
"Submit" => "Send",
"Cancel" => "Annuller",
"Eventinfo" => "Begivenhedsinfo",
"Repeating" => "Gentagende",
"Alarm" => "Alarm",
"Attendees" => "Deltagere",
"Share" => "Del",
"Title of the Event" => "Titel på begivenheden",
"from" => "fra",
"All Day Event" => "Heldagsarrangement",
"Advanced options" => "Avancerede indstillinger",
"Location" => "Sted",
"Edit categories" => "Rediger kategorier",
"Description" => "Beskrivelse",
"Repeat" => "Gentag",
"Advanced" => "Avanceret",
"Select weekdays" => "Vælg ugedage",
"Select days" => "Vælg dage",
"and the events day of year." => "og begivenhedens dag i året.",
"and the events day of month." => "og begivenhedens dag i måneden",
"Select months" => "Vælg måneder",
"Select weeks" => "Vælg uger",
"and the events week of year." => "og begivenhedens uge i året.",
"Interval" => "Interval",
"End" => "Afslutning",
"occurrences" => "forekomster",
"create a new calendar" => "opret en ny kalender",
"Import a calendar file" => "Importer en kalenderfil",
"Please choose a calendar" => "Vælg en kalender",
"Name of new calendar" => "Navn på ny kalender",
"Take an available name!" => "Vælg et ledigt navn!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "En kalender med dette navn findes allerede. Hvis du fortsætter alligevel, vil disse kalendere blive sammenlagt.",
"Remove all events from the selected calendar" => "Fjern alle events fra den valgte kalender",
"Import" => "Importer",
"Close Dialog" => "Luk dialog",
"Create a new event" => "Opret en ny begivenhed",
"Unshare" => "Fjern deling",
"Send Email" => "Send Email",
"Shared via calendar" => "Delt via kalender",
"View an event" => "Vis en begivenhed",
"Category" => "Kategori",
"No categories selected" => "Ingen categorier valgt",
"of" => "fra",
"Access Class" => "Adgangsklasse",
"From" => "Fra",
"at" => "kl.",
"To" => "Til",
"Your calendars" => "Dine kalendere",
"General" => "Generel",
"Timezone" => "Tidszone",
"Update timezone automatically" => "Opdater tidszone automatisk",
"Time format" => "Tidsformat",
"24h" => "24T",
"12h" => "12T",
"Start week on" => "Start ugen med",
"Cache" => "Cache",
"Clear cache for repeating events" => "Ryd cache for gentagende begivenheder",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Adresser til kalendersynkronisering over CalDAV",
"more info" => "flere oplysninger",
"Primary address (Kontact et al)" => "Primær adresse (Kontakt o.a.)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Skrivebeskyttet iCalendar-link(s)"
);

==> owncloud-7.0.4.tgz: owncloud/apps/calendar/l10n/da.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ikke alle kalendere er fuldstændig cached",
"Everything seems to be completely cached" => "Alt ser ud til at være cached",
"No calendars found." => "Der blev ikke fundet nogen kalendere.",
"No events found." => "Der blev ikke fundet nogen begivenheder.",
"Wrong calendar" => "Forkert kalender",
"You do not have the permissions to edit this event." => "Du har ikke rettigheder til at redigere denne begivenhed.",
"The file contained either no events or all events are already saved in your calendar." => "Enten indeholdt filen ingen begivenheder, eller også er alle begivenheder allerede gemt i din kalender.",
"Import failed" => "Import mislykkedes",
"New Timezone:" => "Ny tidszone:",
"Timezone changed" => "Tidszone ændret",
"Invalid request" => "Ugyldig forespørgsel",
"Calendar" => "Kalender",
"Deletion failed" => "Fejl ved sletning",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "gruppe",
"can edit" => "kan redigere",
"can share" => "kan dele",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Søndag",
"Monday" => "Mandag",
"Tuesday" => "Tirsdag",
"Wednesday" => "Onsdag",
"Thursday" => "Torsdag",
"Friday" => "Fredag",
"Saturday" => "Lørdag",
"Sun." => "Søn.",
"Mon." => "Man.",
"Tue." => "Tir.",
"Wed." => "Ons.",
"Thu." => "Tor.",
"Fri." => "Fre.",
"Sat." => "Lør.",
"January" => "Januar",
"February" => "Februar",
"March" => "Marts",
"April" => "April",
"May" => "Maj",
"June" => "Juni",
"July" => "Juli",
"August" => "August",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "December",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Maj",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Hele dagen",
"New Calendar" => "Ny kalender",
"Missing or invalid fields" => "Manglende eller ugyldige felter",
"Title" => "Titel",
"From Date" => "Fra dato",
"From Time" => "Fra tidspunkt",
"To Date" => "Til dato",
"To Time" => "Til tidspunkt",
"The event ends before it starts" => "Begivenheden slutter, inden den begynder",
"There was a database fail" => "Der var en fejl i databasen",
"Birthday" => "Fødselsdag",
"Business" => "Erhverv",
"Call" => "Ring",
"Clients" => "Kunder",
"Deliverer" => "Leverance",
"Holidays" => "Helligdage",
"Ideas" => "Ideer",
"Journey" => "Rejse",
"Jubilee" => "Jubilæum",
"Meeting" => "Møde",
"Other" => "Andet",
"Personal" => "Privat",
"Projects" => "Projekter",
"Questions" => "Spørgsmål",
"Work" => "Arbejde",
"by" => "af",
"unnamed" => "unavngivet",
"You do not have the permissions to update this calendar." => "Du har ikke rettigheder til at opdatere denne kalender.",
"You do not have the permissions to delete this calendar." => "Du har ikke rettigheder til at slette denne kalender.",
"You do not have the permissions to add to this calendar." => "Du har ikke rettigheder til at tilføje til denne kalender.",
"You do not have the permissions to add events to this calendar." => "Du har ikke rettigheder til at tilføje begivenheder til denne kalender.",
"You cannot add non-public events to a shared calendar." => "Du kan ikke tilføje ikke-offentlige begivenheder til en delt kalender.",
"You do not have the permissions to delete this event." => "Du har ikke rettigheder til at slette denne begivenhed.",
"Busy" => "Optaget",
"Show full event" => "Vis den fulde begivenhed",
"Show only busy" => "Vis kun optaget",
"Hide event" => "Skjul begivenhed",
"Does not repeat" => "Gentages ikke",
"Daily" => "Dagligt",
"Weekly" => "Ugentligt",
"Every Weekday" => "Alle hverdage",
"Bi-Weekly" => "Hver anden uge",
"Monthly" => "Månedligt",
"Yearly" => "Årligt",
"never" => "aldrig",
"by occurrences" => "efter forekomster",
"by date" => "efter dato",
"by monthday" => "efter dag i måneden",
"by weekday" => "efter ugedag",
"events week of month" => "begivenhedens uge i måneden",
"first" => "første",
"second" => "anden",
"third" => "tredje",
"fourth" => "fjerde",
"fifth" => "femte",
"last" => "sidste",
"by events date" => "efter begivenheders dato",
"by yearday(s)" => "efter dag(e) i året",
"by weeknumber(s)" => "efter ugenummer/-numre",
"by day and month" => "efter dag og måned",
"Contact birthdays" => "Kontakt fødselsdage",
"Date" => "Dato",
"Cal." => "Kal.",
"Day" => "Dag",
"Week" => "Uge",
"Month" => "Måned",
"Today" => "I dag",
"CalDav Link" => "CalDav-link",
"Timezone" => "Tidszone",
"Update timezone automatically" => "Opdater tidszone automatisk",
"Time format" => "Tidsformat",
"24h" => "24T",
"12h" => "12T",
"Start week on" => "Start ugen med",
"Cache" => "Cache",
"Clear cache for repeating events" => "Ryd cache for gentagende begivenheder",
"Primary CalDAV address" => "Primær CalDAV adresse",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV adresse",
"Share Calendar" => "Del kalender",
"Download" => "Hent",
"Edit" => "Rediger",
"Delete" => "Slet",
"New calendar" => "Ny kalender",
"Edit calendar" => "Rediger kalender",
"Edit event" => "Rediger begivenhed",
"Save event" => "Gem begivenhed",
"Delete event" => "Slet begivenhed",
"Eventinfo" => "Begivenhedsinfo",
"Repeating" => "Gentagende",
"Alarm" => "Alarm",
"Attendees" => "Deltagere",
"Share" => "Del",
"Title of the Event" => "Titel på begivenheden",
"from" => "fra",
"to" => "til",
"All Day Event" => "Heldagsarrangement",
"Advanced options" => "Avancerede indstillinger",
"Location" => "Sted",
"Categories (separate by comma)" => "Kategorier (adskilt af komma)",
"Edit categories" => "Rediger kategorier",
"Description" => "Beskrivelse",
"Export event" => "Eksporter begivenhed",
"Repeat" => "Gentag",
"Advanced" => "Avanceret",
"Select weekdays" => "Vælg ugedage",
"Select days" => "Vælg dage",
"and the events day of year." => "og begivenhedens dag i året.",
"and the events day of month." => "og begivenhedens dag i måneden",
"Select months" => "Vælg måneder",
"Select weeks" => "Vælg uger",
"and the events week of year." => "og begivenhedens uge i året.",
"Interval" => "Interval",
"End" => "Afslutning",
"occurrences" => "forekomster",
"Visibility to people shared with" => "Synlig for personer delt med",
"create a new calendar" => "opret en ny kalender",
"Import a calendar file" => "Importer en kalenderfil",
"Please choose a calendar" => "Vælg en kalender",
"Name of new calendar" => "Navn på ny kalender",
"Take an available name!" => "Vælg et ledigt navn!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "En kalender med dette navn findes allerede. Hvis du fortsætter alligevel, vil disse kalendere blive sammenlagt.",
"Remove all events from the selected calendar" => "Fjern alle events fra den valgte kalender",
"Import" => "Importer",
"Close Dialog" => "Luk dialog",
"Create a new event" => "Opret en ny begivenhed",
"Create event" => "Opret begivenhed",
"Share with user or group" => "Del med bruger eller gruppe",
"Unshare" => "Fjern deling",
"Not shared with anyone" => "Ikke delt med nogen",
"Send Email" => "Send Email",
"Shared via calendar" => "Delt via kalender",
"Not shared with anyone via calendar" => "Ikke delt med nogen via kalender",
"View an event" => "Vis en begivenhed",
"Category" => "Kategori",
"No categories selected" => "Ingen categorier valgt",
"%s of %s" => "%s af %s",
"Access Class" => "Adgangsklasse",
"From" => "Fra",
"at" => "kl.",
"To" => "Til"
);
